# Generated by Django 3.2.1 on 2021-05-06 08:02

import datetime
from django.db import migrations, models
from django.utils.timezone import utc


class Migration(migrations.Migration):

    dependencies = [
        ('drf_auth_service', '0003_auto_20201120_1531'),
    ]

    operations = [
        migrations.AddField(
            model_name='ssouser',
            name='created_at',
            field=models.DateTimeField(default=datetime.datetime(2021, 5, 6, 8, 2, 10, 801289, tzinfo=utc)),
        ),
    ]
